/**********************************************************
Chip type           : ATmega8
Program type        : Application
Clock frequency     : 4,000000 MHz
Memory model        : Small
External SRAM size  : 0
Data Stack size     : 256
***********************************************************/

// CodeVisionAVR C Compiler
// (C) 1998-2004 Pavel Haiduc, HP InfoTech S.R.L.

// I/O registers definitions for the ATmega8


#pragma used+
sfrb TWBR=0;
sfrb TWSR=1;
sfrb TWAR=2;
sfrb TWDR=3;
sfrb ADCL=4;
sfrb ADCH=5;
sfrw ADCW=4;      // 16 bit access
sfrb ADCSRA=6;
sfrb ADMUX=7;
sfrb ACSR=8;
sfrb UBRRL=9;
sfrb UCSRB=0xa;
sfrb UCSRA=0xb;
sfrb UDR=0xc;
sfrb SPCR=0xd;
sfrb SPSR=0xe;
sfrb SPDR=0xf;
sfrb PIND=0x10;
sfrb DDRD=0x11;
sfrb PORTD=0x12;
sfrb PINC=0x13;
sfrb DDRC=0x14;
sfrb PORTC=0x15;
sfrb PINB=0x16;
sfrb DDRB=0x17;
sfrb PORTB=0x18;
sfrb EECR=0x1c;
sfrb EEDR=0x1d;
sfrb EEARL=0x1e;
sfrb EEARH=0x1f;
sfrw EEAR=0x1e;   // 16 bit access
sfrb UBRRH=0x20;
sfrb UCSRC=0X20;
sfrb WDTCR=0x21;
sfrb ASSR=0x22;
sfrb OCR2=0x23;
sfrb TCNT2=0x24;
sfrb TCCR2=0x25;
sfrb ICR1L=0x26;
sfrb ICR1H=0x27;
sfrw ICR1=0x26;   // 16 bit access
sfrb OCR1BL=0x28;
sfrb OCR1BH=0x29;
sfrw OCR1B=0x28;  // 16 bit access
sfrb OCR1AL=0x2a;
sfrb OCR1AH=0x2b;
sfrw OCR1A=0x2a;  // 16 bit access
sfrb TCNT1L=0x2c;
sfrb TCNT1H=0x2d;
sfrw TCNT1=0x2c;  // 16 bit access
sfrb TCCR1B=0x2e;
sfrb TCCR1A=0x2f;
sfrb SFIOR=0x30;
sfrb OSCCAL=0x31;
sfrb TCNT0=0x32;
sfrb TCCR0=0x33;
sfrb MCUCSR=0x34;
sfrb MCUCR=0x35;
sfrb TWCR=0x36;
sfrb SPMCR=0x37;
sfrb TIFR=0x38;
sfrb TIMSK=0x39;
sfrb GIFR=0x3a;
sfrb GICR=0x3b;
sfrb SPL=0x3d;
sfrb SPH=0x3e;
sfrb SREG=0x3f;
#pragma used-

// Interrupt vectors definitions


// Needed by the power management functions (sleep.h)
#asm
	#ifndef __SLEEP_DEFINED__
	#define __SLEEP_DEFINED__
	.EQU __se_bit=0x80
	.EQU __sm_mask=0x70
	.EQU __sm_powerdown=0x20
	.EQU __sm_powersave=0x30
	.EQU __sm_standby=0x60
	.EQU __sm_ext_standby=0x70
	.EQU __sm_adc_noise_red=0x10
	.SET power_ctrl_reg=mcucr
	#endif
#endasm



//------------  -----------------------
void delay(unsigned int a)
{unsigned int cnt;
 for (cnt=a; cnt>0; cnt--);
}    
//------------    -------------------
void lcd_com(unsigned char c)
{unsigned int cmd; 
 cmd=c;                      //      
 PORTC.4     =0;                       //  
 PORTC.5      =1;                        //enable = 1
 PORTC &=0xF0;             //   
 PORTC =PORTC |(cmd>>4); //  
 delay(80        );                //
 PORTC.5      =0;                        // 
 delay(80        );                //
 PORTC.5      =1;                        //enable = 1
 PORTC &=0xF0;             //  
 PORTC =PORTC |(c&0x0F); //  
 delay(80        );                //    
 PORTC.5      =0;                        //  
 delay(5*80        );              //       
}
//-----------    ---------------------
void lcd_putchar(unsigned char d)
 {unsigned int dat;
  dat=d;                      //  
  PORTC.4     =1;                       //  
  PORTC.5      =1;                        //enable = 1
  PORTC &=0xF0;             //  
  PORTC =PORTC |(dat>>4); //  
  delay(80        );                //
  PORTC.5      =0;                        //
  delay(80        );                //
  PORTC.5      =1;                        //enable = 1
  PORTC &=0xF0;             //  
  PORTC =PORTC |(d&0x0F); //  
  delay(80        );                //    
  PORTC.5      =0;                        //
  delay(5*80        );              //       
 }    
//-------------  ---------------------------
void lcd_clear(void)
{lcd_com(0x01); delay(80        *1000);// 
}
//-----------  -----------------------
void lcd_init(void)
{delay(80        *100);                // 
 lcd_com(0x33); delay(80        *500); //
 lcd_com(0x32); lcd_com(0x28);   //4 , 2  (. Datasheet-s)
 lcd_com(0x08);                  // 
 lcd_clear();                    // 
 lcd_com(0x06);                  //  
 lcd_com(0x0C);                  //  
 delay(80        *5);                  //       
}         
//----------    ---------------------
void lcd_puts(char *str)
{char i;
 while (i=*str++) lcd_putchar(i);
}
//--------      FLASH--------------
void lcd_putsf(char flash *str)
{char i;
while (i=*str++) lcd_putchar(i);
}
//--------     --------------
void lcd_gotoxy(unsigned char x, unsigned char y)
{
 lcd_com((0x80+y*64)+x); // .  080 - . . 
}
//------- ------------------------------------
void main(void)
{
//   C
// Func6=Out Func5=Out Func4=Out Func3=Out Func2=Out Func1=Out Func0=Out 
// State6=0 State5=0 State4=0 State3=0 State2=0 State1=0 State0=0 
PORTC=0x00;
DDRC=0x7F;

lcd_init();
lcd_gotoxy(1,0);
lcd_putsf("Hello, World!");
lcd_gotoxy(0,1);
lcd_putsf("www.roboforum.ru");
}
